# -*- coding: utf-8 -*-


def test_llama_model():
    import os
    os.environ['BiLLM_START_INDEX'] = '-1'

    from billm import LlamaModel, LlamaConfig

    model = LlamaModel(LlamaConfig(vocab_size=128,
                                   hidden_size=32,
                                   intermediate_size=64,
                                   num_hidden_layers=2,
                                   num_attention_heads=2))
    assert model is not None



# -*- coding: utf-8 -*-

import os
import logging

# set start index for BiLLM, default is 0. If set to -1, it will disable BiLLM.
BiLLM_START_INDEX = int(os.getenv('BiLLM_START_INDEX', 0))

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger('BiLLM')
